==> opensubdiv-3.6.1-2.1-x86_64_v4.pkg.tar.zst: usr/share/doc/opensubdiv/doxy_html/a00749.js <==
var a00749 =
[
    [ "MeshInterface< PATCH_TABLE >", "a01252.html", "a01252" ],
    [ "EvaluatorCacheT< EVALUATOR >", "a01256.html", "a01256" ],
    [ "EvaluatorCacheT< EVALUATOR >::Entry", "a01260.html", "a01260" ],
    [ "Mesh< VERTEX_BUFFER, STENCIL_TABLE, EVALUATOR, PATCH_TABLE, DEVICE_CONTEXT >", "a01264.html", "a01264" ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshBitset", "a00903.html#a85ba9df501aea9af1ec9da1558c255bc", null ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshBits", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492", [
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshAdaptive", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492adef344bcbdd50a1a93136eb53183c718", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterleaveVarying", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9313c644b9b2a998bcb55cfcc4582b1a", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshFVarData", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492ac10e41fef659f3b3a1b730319bdedb45", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshFVarAdaptive", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9b8a23ab039e120012bc7c622308d603", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshUseSmoothCornerPatch", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492ab32b8ef595539e14041e2fb0e619e3f9", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshUseSingleCreasePatch", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9058d69e1089fc77f1974a76c34e2071", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshUseInfSharpPatch", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a8fab1b3018f94b5b2432c7435e795925", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshEndCapBilinearBasis", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a4124233e4f787f999c7975afceab34f3", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshEndCapBSplineBasis", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aa2f41b6ba0393698bb3af283283737f7", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshEndCapGregoryBasis", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aa2878e1a215530f5f6fb89f1e06f91ee", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshEndCapLegacyGregory", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aad7b3fb2be609abdbfafaf5b1c834158", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::NUM_MESH_BITS", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a5676712c77d29cfdd330e2802db1c464", null ]
    ] ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::convertToCompatibleStencilTable", "a00903.html#a06ceddf21c024b341a5b946049cd701a", null ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::convertToCompatibleStencilTable< Far::LimitStencilTable, Far::LimitStencilTable, void >", "a00903.html#a4c2520cc1a8a5a03e3f53584629d7318", null ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::convertToCompatibleStencilTable< Far::StencilTable, Far::StencilTable, ID3D11DeviceContext >", "a00903.html#ab5753a2b0a0995c8e2259d2c4765f7df", null ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::convertToCompatibleStencilTable< Far::StencilTable, Far::StencilTable, void >", "a00903.html#a33f9830228f847fae1c30c9dffe02b5a", null ]
];

==> opensubdiv-3.7.0-1.1-x86_64_v4.pkg.tar.zst: usr/share/doc/opensubdiv/doxy_html/a00749.js <==
var a00749 =
[
    [ "MeshInterface&lt; PATCH_TABLE &gt;", "a01252.html", "a01252" ],
    [ "EvaluatorCacheT&lt; EVALUATOR &gt;", "a01256.html", "a01256" ],
    [ "EvaluatorCacheT&lt; EVALUATOR &gt;::Entry", "a01260.html", "a01260" ],
    [ "Mesh&lt; VERTEX_BUFFER, STENCIL_TABLE, EVALUATOR, PATCH_TABLE, DEVICE_CONTEXT &gt;", "a01264.html", "a01264" ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshBitset", "a00903.html#a85ba9df501aea9af1ec9da1558c255bc", null ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshBits", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492", [
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshAdaptive", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492adef344bcbdd50a1a93136eb53183c718", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshInterleaveVarying", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9313c644b9b2a998bcb55cfcc4582b1a", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshFVarData", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492ac10e41fef659f3b3a1b730319bdedb45", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshFVarAdaptive", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9b8a23ab039e120012bc7c622308d603", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshUseSmoothCornerPatch", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492ab32b8ef595539e14041e2fb0e619e3f9", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshUseSingleCreasePatch", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9058d69e1089fc77f1974a76c34e2071", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshUseInfSharpPatch", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a8fab1b3018f94b5b2432c7435e795925", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshEndCapBilinearBasis", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a4124233e4f787f999c7975afceab34f3", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshEndCapBSplineBasis", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aa2f41b6ba0393698bb3af283283737f7", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshEndCapGregoryBasis", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aa2878e1a215530f5f6fb89f1e06f91ee", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::MeshEndCapLegacyGregory", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aad7b3fb2be609abdbfafaf5b1c834158", null ],
      [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::NUM_MESH_BITS", "a00903.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a5676712c77d29cfdd330e2802db1c464", null ]
    ] ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::convertToCompatibleStencilTable", "a00903.html#a06ceddf21c024b341a5b946049cd701a", null ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::convertToCompatibleStencilTable< Far::LimitStencilTable, Far::LimitStencilTable, void >", "a00903.html#a4c2520cc1a8a5a03e3f53584629d7318", null ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::convertToCompatibleStencilTable< Far::StencilTable, Far::StencilTable, ID3D11DeviceContext >", "a00903.html#ab5753a2b0a0995c8e2259d2c4765f7df", null ],
    [ "OpenSubdiv::OPENSUBDIV_VERSION::Osd::convertToCompatibleStencilTable< Far::StencilTable, Far::StencilTable, void >", "a00903.html#a33f9830228f847fae1c30c9dffe02b5a", null ]
];
